@@ -6,7 +6,7 @@
 #     /_/  |_/_/\__,_/\___/\____/_/   \__,_/\___/_/     
 #
 #
-#       ALACORDER beta 70.5.2
+#       ALACORDER beta 70.5
 #       by Sam Robson
 #
 
@@ -37,10 +37,11 @@ def config(in_path, out_path="", flags="", print_log=True, warn=False, save_arch
 	input_cap = True if max_cases > 0 else False
 	out_ext: str = out_path.split(".")[-1].strip()
 	
-	if path_input == True:
+	try:
 		in_ext: str = in_path.split(".")[-1].strip() if len(in_path.split(".")[-1])<5 else "directory" 
-	else:
-		in_ext = "object"
+		path_input = True
+	except IndexError:
+		in_ext = "directory"
 		in_path = "no_import"
 		origin = "archive"
 		make = "table"
@@ -88,10 +89,13 @@ def config(in_path, out_path="", flags="", print_log=True, warn=False, save_arch
 			contents = textfile.read()
 			if print_log == True:
 				print(contents)
-	if in_ext == "directory" and bool(out_ext == "xls" or  out_ext == "no_export" or out_ext == "json" or out_ext == "csv" or out_ext == "txt" or out_ext == "dta"):
+	if bool(in_ext == "directory" or in_ext == "pdf") and bool(out_ext == "xls" or  out_ext == "no_export" or out_ext == "json" or out_ext == "csv" or out_ext == "txt" or out_ext == "dta"):
 		make = "table"
 		origin = "directory"
-		paths = glob.glob(in_path + '**/*.pdf', recursive=True)
+		if in_ext == "directory":
+			paths = glob.glob(in_path + '**/*.pdf', recursive=True)
+		else:
+			contents = alac.getPDFText(in_path)
 		if print_log == True:
 			print(paths)
 	if in_ext == "pkl":
@@ -985,17 +989,9 @@ def log_complete(conf, start_time):
 	completion_time = time.time()
 	elapsed = completion_time - start_time
 	cases_per_sec = max_cases/elapsed
-	print(f'''\n\n
+	print(f'''
 
-		  ___    __                          __         
-		 /   |  / /___  _________  _________/ /__  _____
-		/ /| | / / __ `/ ___/ __ \\/ ___/ __  / _ \\/ ___/
-	   / ___ |/ / /_/ / /__/ /_/ / /  / /_/ /  __/ /    
-	  /_/  |_/_/\\__,_/\\___/\\____/_/   \\__,_/\\___/_/     
-
-
-
-	ALACORDER beta 70.5.2
+	ALACORDER beta 70.5
 	by Sam Robson   
 
 	Searched {path_in} 
